    #!/bin/sh
    #================================================================================
    # (C)2013 dMajo
    # Title       : ad-blocker.sh
    # Version     : V2.00.0002
    # Orig Author : dMajo (http://forum.synology.com/enu/memberlist.php?mode=viewprofile&u=69661)
    # Description : Script to block add-banner servers, dns based
    # Dependencies: Syno DNSServer package, sed, wget
    # Usage       : sh ad-blocker.sh
    #================================================================================
    # Version history:
    # 2013.09.01 - 1.00.0001: Initial release
    # 2013.09.08 - 1.00.0004: Fix: changed include target to support views
    # 2013.09.12 - 1.00.0005: Added automatic zone file generation and some basic error handling
    # 2014.03.29 - 1.01.0013: Added dependencies check
    # 2014.03.30 - 1.02.0017: Script reorganized
    # 2014.04.06 - 1.02.0018: Fix: fixed serial number in zone file generation
	#
	# Edits by	  : SmiGueL
	# 2016.09.08 - 			  Adding blacklist + whitelist feature
	# 2016.09.15 - 			  Adding multiple websites to download hostslists from
	# 2016.09.16 - 2.00.0001  Fixed serial number error to prevent log errors when updating more than once a day
	# 2016.09.29 - 2.00.0002  Added Quidups's tracker blocklist
	#
	# Edit by     : Briolet
	# 2017.02.29 - 2.00.0003  Also export the final list to the temp folder
	
	# 						  
    #================================================================================
	
    # Define variables
	CustomLists="$(cd "$(dirname "${BASH_SOURCE[0]}")" && pwd)/" # path to this script | for storing the white & blacklists
	# CustomLists="/volume1/Logs/DNSfiles"		#Directory path of blacklist & whitelist when you want to store is at another location as the script itself
	YoyoList=1									#3k			#1 to enable or 0 to disable | Automatically import updated version of the yoyo.org blocklist							http://pgl.yoyo.org/as/serverlist.php?hostformat=bindconfig&showintro=0&mimetype=plaintext
	Malwaredomains2=0							#17k		#1 to enable or 0 to disable | Automatically import updated version of the malwaredomains.com blocklist					http://mirror2.malwaredomains.com/files/spywaredomains.zones
	RandomLargeList=0							#34k		#1 to enable or 0 to disable | Automatically import a large Github blocklist (last updated  )							https://raw.githubusercontent.com/mat1th/Dns-add-block/master/adresses
	PiHoleList=1								#27k		#1 to enable or 0 to disable | Automatically import updated version of the official Pi-Hole blocklist					https://raw.githubusercontent.com/StevenBlack/hosts/master/hosts
															#| This Pi-Hole list includes: a custom list + malwaredomainlist.com + WinHelp2002 + someonewhocares + yoyo.org 		https://github.com/pi-hole/pi-hole/blob/master/adlists.default
	Malwaredomains1=0							#17k		#1 to enable or 0 to disable | Automatically import updated version of malwaredomains blocklist							http://mirror1.malwaredomains.com/files/justdomains
	sysct1=0									#21k		#1 to enable or 0 to disable | Automatically import updated version of sysct1 blocklist									http://sysctl.org/cameleon/hosts
	amazonws1=0									#0k			#1 to enable or 0 to disable | Automatically import updated version of amazonsw blocklist								https://s3.amazonaws.com/lists.disconnect.me/simple_tracking.txt
	amazonws2=0									#3k			#1 to enable or 0 to disable | Automatically import updated version of amazonsw blocklist								https://s3.amazonaws.com/lists.disconnect.me/simple_ad.txt
	HostsFileNet=0								#48k		#1 to enable or 0 to disable | Automatically import updated version of hosts-file.net blocklist							https://hosts-file.net/ad_servers.txt
	Quidsupstracker=0							#11k		#1 to enable or 0 to disable | Automatically import updated version of Quidups's tracker blocklist						https://raw.githubusercontent.com/quidsup/notrack/master/trackers.txt
	
	
    RootDir="/var/packages/DNSServer/target"
    ZoneDir="${RootDir}/named/etc/zone"
    ZoneDataDir="${ZoneDir}/data"
    ZoneMasterDir="${ZoneDir}/master"


    cd ${ZoneDataDir}

    # Check if needed dependencies exists
       Dependencies="chown date grep mv rm sed wget"
       MissingDep=0
       for NeededDep in $Dependencies; do
          if ! hash "$NeededDep" >/dev/null 2>&1; then
             printf "Command not found in PATH: %s\n" "$NeededDep" >&2
             MissingDep=$((MissingDep+1))
          fi
       done
       if [ $MissingDep -gt 0 ]; then
          printf "Minimum %d commands are missing in PATH, aborting\n" "$MissingDep" >&2
          exit 1
       fi

if [[ "$YoyoList" -eq 1 ]]; then
    # Download the "blacklist" from "http://pgl.yoyo.org"
        wget "http://pgl.yoyo.org/as/serverlist.php?hostformat=bindconfig&showintro=0&mimetype=plaintext"
fi

    # Modify Zone file path from "null.zone.file" to "/etc/zone/master/null.zone.file" in order to comply with Synology bind implementation
		rm -f ad-blocker.new
		sed -e 's/null.zone.file/\/etc\/zone\/master\/null.zone.file/g' "serverlist.php?hostformat=bindconfig&showintro=0&mimetype=plaintext" > ad-blocker.new
		rm "serverlist.php?hostformat=bindconfig&showintro=0&mimetype=plaintext"
		cp ad-blocker.new ${CustomLists}/temp/yoyo.txt
		chown -R nobody:nobody ad-blocker.new
		if [ -f ad-blocker.new ] ; then
			rm -f ad-blocker.db
			mv ad-blocker.new ad-blocker.db
		fi


		mkdir -p ${CustomLists}/temp



if [[ "$Malwaredomains2" -eq 1 ]]; then
	# Download blocklist from malwaredomains.com
	wget "http://mirror2.malwaredomains.com/files/spywaredomains.zones"
	sed -e 's/  {type master; file "\/etc\/namedb\/blockeddomain.hosts";}; / { type master; notify no; file "\/etc\/zone\/master\/null.zone.file"; };/g' "spywaredomains.zones" > ${CustomLists}/temp/malwaredomains20.txt
	rm "spywaredomains.zones"
	echo "" >> ${CustomLists}/temp/malwaredomains20.txt
	sed -e "s/\r/\n/g" ${CustomLists}/temp/malwaredomains20.txt > ${CustomLists}/temp/malwaredomains21.txt
	sed -e "s/\n\n/\n/g" ${CustomLists}/temp/malwaredomains21.txt > ${CustomLists}/temp/malwaredomains22.txt
	sed '/^\s*$/d' ${CustomLists}/temp/malwaredomains22.txt > ${CustomLists}/temp/malwaredomains23.txt 		# Remove all empty lines
	sed '/_/d' ${CustomLists}/temp/malwaredomains23.txt > ${CustomLists}/temp/malwaredomains24.txt	# Remove all lines with underscore chars
	
	# Add the malwaredomainlist to the blocklist
	cat ${CustomLists}/temp/malwaredomains24.txt >> ad-blocker.db
fi



if [[ "$RandomLargeList" -eq 1 ]]; then
	# Download random blocklist from github (not updated)
	wget "https://github.com/mat1th/Dns-add-block/blob/master/adresses?raw=true"
	mv adresses?raw=true ${CustomLists}/temp/randomlargelist10.txt
	echo "" >> ${CustomLists}/temp/randomlargelist10.txt
	
	sed -e "s/\r/\n/g" ${CustomLists}/temp/randomlargelist10.txt > ${CustomLists}/temp/randomlargelist11.txt
	sed -e "s/\n\n/\n/g" ${CustomLists}/temp/randomlargelist11.txt > ${CustomLists}/temp/randomlargelist12.txt
	sed -e s/"  "/" "/g ${CustomLists}/temp/randomlargelist12.txt > ${CustomLists}/temp/randomlargelist13.txt
	sed '/_/d' ${CustomLists}/temp/randomlargelist13.txt > ${CustomLists}/temp/randomlargelist14.txt	# Remove all lines with underscore chars
	sed '/:/d' ${CustomLists}/temp/randomlargelist14.txt > ${CustomLists}/temp/randomlargelist15.txt	# Remove all lines with colon
	echo "" >> ${CustomLists}/temp/randomlargelist15.txt
	sort ${CustomLists}/temp/randomlargelist15.txt | uniq > ${CustomLists}/temp/randomlargelist16.txt
	

	cat ${CustomLists}/temp/randomlargelist16.txt >> ad-blocker.db
fi



if [[ "$PiHoleList" -eq 1 ]]; then
	# Download blocklist from Pi-Hole
	wget "https://raw.githubusercontent.com/StevenBlack/hosts/master/hosts"
	mv hosts ${CustomLists}/temp/piholelist.txt

	sed -e '/^0.0.0.0/!d' ${CustomLists}/temp/piholelist.txt> ${CustomLists}/temp/piholelist1.txt	# Remove all lines that does not start with 0.0.0.0
	sed 's/#.*//' ${CustomLists}/temp/piholelist1.txt > ${CustomLists}/temp/piholelist2.txt	# Remove all after #
	sed 's/ *$//' ${CustomLists}/temp/piholelist2.txt > ${CustomLists}/temp/piholelist3.txt	# Remove all spaces at the end of the line (Needed after the REMOVE # command)
	sed -e 's/\(.*\)/\L\1/' ${CustomLists}/temp/piholelist3.txt > ${CustomLists}/temp/piholelist4.txt	# Replace capital chars
	sed '/_/d' ${CustomLists}/temp/piholelist4.txt > ${CustomLists}/temp/piholelist5.txt	# Remove all lines with underscore chars
	sed -e 's/0.0.0.0 /zone "/g' ${CustomLists}/temp/piholelist5.txt > ${CustomLists}/temp/piholelist6.txt	# Replace beginning of line 0.0.0.0  by zone "
	sed -e 's/$/" { type master; notify no; file "\/etc\/zone\/master\/null.zone.file"; };/g' ${CustomLists}/temp/piholelist6.txt > ${CustomLists}/temp/piholelist7.txt	# Replace end of line \n or LF by " { type master; notify no; file "/etc/zone/master/null.zone.file";  };

	cat ${CustomLists}/temp/piholelist7.txt >> ad-blocker.db	# Add the spywaredomainlist to the blocklist
fi



if [[ "$Malwaredomains1" -eq 1 ]]; then
	# Download blocklist from malwaredomains.com
	wget "http://mirror1.malwaredomains.com/files/justdomains"
	mv justdomains ${CustomLists}/temp/malwaredomains10.txt
	echo "" >> ${CustomLists}/temp/malwaredomains10.txt
	
	sed 's/#.*//' ${CustomLists}/temp/malwaredomains10.txt > ${CustomLists}/temp/malwaredomains12.txt 	# Remove all after #
	sed 's/ *$//' ${CustomLists}/temp/malwaredomains12.txt > ${CustomLists}/temp/malwaredomains13.txt 	# Remove all spaces at the end of the line (Needed after the REMOVE # command)
	sed '/^\s*$/d' ${CustomLists}/temp/malwaredomains13.txt > ${CustomLists}/temp/malwaredomains14.txt 		# Remove all empty lines
	sed -e 's/\(.*\)/\L\1/' ${CustomLists}/temp/malwaredomains14.txt > ${CustomLists}/temp/malwaredomains15.txt 	# Replace capital chars
	sed '/_/d' ${CustomLists}/temp/malwaredomains15.txt > ${CustomLists}/temp/malwaredomains16.txt	# Remove all lines with underscore chars
	sed -e 's/^/zone "/g' ${CustomLists}/temp/malwaredomains16.txt > ${CustomLists}/temp/malwaredomains17.txt 	# Replace beginning of line 127.0.0.1  by zone "
	sed -e 's/$/" { type master; notify no; file "\/etc\/zone\/master\/null.zone.file"; };/g' ${CustomLists}/temp/malwaredomains17.txt > ${CustomLists}/temp/malwaredomains18.txt # Replace end of line \n or LF by " { type master; notify no; file "/etc/zone/master/null.zone.file";  };
	
	cat ${CustomLists}/temp/malwaredomains18.txt >> ad-blocker.db
fi



if [[ "$sysct1" -eq 1 ]]; then
	# Download blocklist from sysct1.com
	wget "http://sysctl.org/cameleon/hosts"
	mv hosts ${CustomLists}/temp/sysct1.txt
	echo "" >> ${CustomLists}/temp/sysct1.txt
	
	sed -e '/^127.0.0.1\t /!d' ${CustomLists}/temp/sysct1.txt> ${CustomLists}/temp/sysct11.txt 	# Remove all lines that does not start with 127.0.0.1
	sed 's/#.*//' ${CustomLists}/temp/sysct11.txt > ${CustomLists}/temp/sysct12.txt 	# Remove all after #
	sed 's/ *$//' ${CustomLists}/temp/sysct12.txt > ${CustomLists}/temp/sysct13.txt 	# Remove all spaces at the end of the line (Needed after the REMOVE # command)
	sed -e 's/\(.*\)/\L\1/' ${CustomLists}/temp/sysct13.txt > ${CustomLists}/temp/sysct14.txt 	# Replace capital chars
	sed '/_/d' ${CustomLists}/temp/sysct14.txt > ${CustomLists}/temp/sysct15.txt	# Remove all lines with underscore chars
	sed -e 's/127.0.0.1\t /zone "/g' ${CustomLists}/temp/sysct15.txt > ${CustomLists}/temp/sysct16.txt 	# Replace beginning of line 127.0.0.1  by zone "
	sed -e 's/$/" { type master; notify no; file "\/etc\/zone\/master\/null.zone.file"; };/g' ${CustomLists}/temp/sysct16.txt > ${CustomLists}/temp/sysct17.txt # Replace end of line \n or LF by " { type master; notify no; file "/etc/zone/master/null.zone.file";  };
	
	cat ${CustomLists}/temp/sysct17.txt >> ad-blocker.db
fi



if [[ "$amazonws1" -eq 1 ]]; then
	# Download blocklist from amazonanews.com
	wget "https://s3.amazonaws.com/lists.disconnect.me/simple_tracking.txt"
	mv simple_tracking.txt ${CustomLists}/temp/amazonaws10.txt
	echo "" >> ${CustomLists}/temp/amazonaws10.txt
	
	sed 's/#.*//' ${CustomLists}/temp/amazonaws10.txt > ${CustomLists}/temp/amazonaws12.txt 	# Remove all after #
	sed 's/ *$//' ${CustomLists}/temp/amazonaws12.txt > ${CustomLists}/temp/amazonaws13.txt 	# Remove all spaces at the end of the line (Needed after the REMOVE # command)
	sed '/^\s*$/d' ${CustomLists}/temp/amazonaws13.txt > ${CustomLists}/temp/amazonaws14.txt 		# Remove all empty lines
	sed -e 's/\(.*\)/\L\1/' ${CustomLists}/temp/amazonaws14.txt > ${CustomLists}/temp/amazonaws15.txt 	# Replace capital chars
	sed '/_/d' ${CustomLists}/temp/amazonaws15.txt > ${CustomLists}/temp/amazonaws16.txt	# Remove all lines with underscore chars
	sed -e 's/^/zone "/g' ${CustomLists}/temp/amazonaws16.txt > ${CustomLists}/temp/amazonaws17.txt 	# Replace beginning of line 127.0.0.1  by zone "
	sed -e 's/$/" { type master; notify no; file "\/etc\/zone\/master\/null.zone.file"; };/g' ${CustomLists}/temp/amazonaws17.txt > ${CustomLists}/temp/amazonaws18.txt # Replace end of line \n or LF by " { type master; notify no; file "/etc/zone/master/null.zone.file";  };
	
	cat ${CustomLists}/temp/amazonaws18.txt >> ad-blocker.db
fi



if [[ "$amazonws2" -eq 1 ]]; then
	# Download blocklist from amazonanews.com
	wget "https://s3.amazonaws.com/lists.disconnect.me/simple_ad.txt"
	mv simple_ad.txt ${CustomLists}/temp/amazonaws20.txt
	echo "" >> ${CustomLists}/temp/amazonaws20.txt
	
	sed 's/#.*//' ${CustomLists}/temp/amazonaws20.txt > ${CustomLists}/temp/amazonaws22.txt 	# Remove all after #
	sed 's/ *$//' ${CustomLists}/temp/amazonaws22.txt > ${CustomLists}/temp/amazonaws23.txt 	# Remove all spaces at the end of the line (Needed after the REMOVE # command)
	sed '/^\s*$/d' ${CustomLists}/temp/amazonaws23.txt > ${CustomLists}/temp/amazonaws24.txt 		# Remove all empty lines
	sed -e 's/\(.*\)/\L\1/' ${CustomLists}/temp/amazonaws24.txt > ${CustomLists}/temp/amazonaws25.txt 	# Replace capital chars
	sed '/_/d' ${CustomLists}/temp/amazonaws25.txt > ${CustomLists}/temp/amazonaws26.txt	# Remove all lines with underscore chars
	sed -e 's/^/zone "/g' ${CustomLists}/temp/amazonaws26.txt > ${CustomLists}/temp/amazonaws27.txt 	# Replace beginning of line 127.0.0.1  by zone "
	sed -e 's/$/" { type master; notify no; file "\/etc\/zone\/master\/null.zone.file"; };/g' ${CustomLists}/temp/amazonaws27.txt > ${CustomLists}/temp/amazonaws28.txt # Replace end of line \n or LF by " { type master; notify no; file "/etc/zone/master/null.zone.file";  };
	
	cat ${CustomLists}/temp/amazonaws28.txt >> ad-blocker.db
fi



if [[ "$HostsFileNet" -eq 1 ]]; then
	# Download blocklist from hosts-file.net
	wget "https://hosts-file.net/ad_servers.txt"
	mv ad_servers.txt ${CustomLists}/temp/hostsfilenet.txt

	sed -e "s/\r/\n/g" ${CustomLists}/temp/hostsfilenet.txt > ${CustomLists}/temp/hostsfilenet1.txt
	sed -e "s/\n\n/\n/g" ${CustomLists}/temp/hostsfilenet1.txt > ${CustomLists}/temp/hostsfilenet2.txt
	sed '/^\s*$/d' ${CustomLists}/temp/hostsfilenet2.txt > ${CustomLists}/temp/hostsfilenet3.txt 		# Remove all empty lines
	sed -e '/^127.0.0.1\t/!d' ${CustomLists}/temp/hostsfilenet3.txt> ${CustomLists}/temp/hostsfilenet4.txt	# Remove all lines that does not start with 127.0.0.1 + tab
	sed 's/#.*//' ${CustomLists}/temp/hostsfilenet4.txt > ${CustomLists}/temp/hostsfilenet5.txt	# Remove all after #
	sed 's/ *$//' ${CustomLists}/temp/hostsfilenet5.txt > ${CustomLists}/temp/hostsfilenet6.txt	# Remove all spaces at the end of the line (Needed after the REMOVE # command)
	sed -e 's/\(.*\)/\L\1/' ${CustomLists}/temp/hostsfilenet6.txt > ${CustomLists}/temp/hostsfilenet7.txt	# Replace capital chars
	sed '/_/d' ${CustomLists}/temp/hostsfilenet7.txt > ${CustomLists}/temp/hostsfilenet8.txt	# Remove all lines with underscore chars
	sed 's/\.$//' ${CustomLists}/temp/hostsfilenet8.txt > ${CustomLists}/temp/hostsfilenet9.txt 	# Remove all dots at the end of the line (Needed because of theoads.com. website....)
	sed -e 's/127.0.0.1\t/zone "/g' ${CustomLists}/temp/hostsfilenet9.txt > ${CustomLists}/temp/hostsfilenet10.txt	# Replace beginning of line 127.0.0.1  by zone "
	sed -e 's/$/" { type master; notify no; file "\/etc\/zone\/master\/null.zone.file"; };/g' ${CustomLists}/temp/hostsfilenet10.txt > ${CustomLists}/temp/hostsfilenet11.txt	# Replace end of line \n or LF by " { type master; notify no; file "/etc/zone/master/null.zone.file";  };

	cat ${CustomLists}/temp/hostsfilenet11.txt >> ad-blocker.db	# Add the spywaredomainlist to the blocklist
fi



if [[ "$Quidsupstracker" -eq 1 ]]; then
	# Download tracker blocklist from Quidups
	wget "https://raw.githubusercontent.com/quidsup/notrack/master/trackers.txt"
	mv trackers.txt ${CustomLists}/temp/quidups1.txt
	echo "" >> ${CustomLists}/temp/quidups1.txt
	
	sed 's/#.*//' ${CustomLists}/temp/quidups1.txt > ${CustomLists}/temp/quidups2.txt 	# Remove all after #
	sed 's/ *$//' ${CustomLists}/temp/quidups2.txt > ${CustomLists}/temp/quidups3.txt 	# Remove all spaces at the end of the line (Needed after the REMOVE # command)
	sed '/^\s*$/d' ${CustomLists}/temp/quidups3.txt > ${CustomLists}/temp/quidups4.txt 		# Remove all empty lines
	sed -e 's/\(.*\)/\L\1/' ${CustomLists}/temp/quidups4.txt > ${CustomLists}/temp/quidups5.txt 	# Replace capital chars
	sed '/_/d' ${CustomLists}/temp/quidups5.txt > ${CustomLists}/temp/quidups6.txt	# Remove all lines with underscore chars
	sed -e 's/^/zone "/g' ${CustomLists}/temp/quidups6.txt > ${CustomLists}/temp/quidups7.txt 	# Replace beginning of line 127.0.0.1  by zone "
	sed -e 's/$/" { type master; notify no; file "\/etc\/zone\/master\/null.zone.file"; };/g' ${CustomLists}/temp/quidups7.txt > ${CustomLists}/temp/quidups8.txt # Replace end of line \n or LF by " { type master; notify no; file "/etc/zone/master/null.zone.file";  };
	
	cat ${CustomLists}/temp/quidups8.txt >> ad-blocker.db
fi







	# New lines \n will be added at the end of the custom Blacklist + Whitelist they can be sorted afterwards.
	# Imported blacklists without \n aka LF at the end will get concatenated and thus not sortable.
	# This prevents the whitelist from working, because only after sorting the double lines can be removed.
	sed -e "s/\r/\n/g" ${CustomLists}/blacklist.txt > ${CustomLists}/temp/blacklist.clean1.txt
	sed -e "s/\n\n/\n/g" ${CustomLists}/temp/blacklist.clean1.txt > ${CustomLists}/temp/blacklist.clean2.txt
	sed -e s/"  "/" "/g ${CustomLists}/temp/blacklist.clean2.txt > ${CustomLists}/temp/blacklist.clean4.txt
	echo "" >> ${CustomLists}/temp/blacklist.clean4.txt

	sed -e "s/\r/\n/g" ${CustomLists}/whitelist.txt > ${CustomLists}/temp/whitelist.clean1.txt
	sed -e "s/\n\n/\n/g" ${CustomLists}/temp/whitelist.clean1.txt > ${CustomLists}/temp/whitelist.clean2.txt
	sed -e s/"  "/" "/g ${CustomLists}/temp/whitelist.clean2.txt > ${CustomLists}/temp/whitelist.clean4.txt
	echo "" >> ${CustomLists}/temp/whitelist.clean4.txt



	# Add the custom Blacklist to the blocklist
	cat ${CustomLists}/temp/blacklist.clean4.txt >> ad-blocker.db
	
	# Replace the capital chars | Sort the Blacklist | Then remove the double ones
	sed -e 's/\(.*\)/\L\1/' ad-blocker.db > ad-blocker.temp1.db
	mv ad-blocker.temp1.db ad-blocker.db
	sort ad-blocker.db | uniq > ad-blocker.temp2.db
	mv ad-blocker.temp2.db ad-blocker.db



	# Add the custom  Whitelist to the blocklist
	cat ${CustomLists}/temp/whitelist.clean4.txt >> ad-blocker.db
	cat ${CustomLists}/temp/whitelist.clean4.txt >> ad-blocker.db
		
	# Sort the blacklist + whitelist | Then remove the double ones (whitelist)
	sort ad-blocker.db | uniq -u > ad-blocker.temp.db
	mv ad-blocker.temp.db ad-blocker.db
    cp ad-blocker.db ${CustomLists}/temp/final-list.txt


    # Include the new zone data
       if [ -f ad-blocker.db ] && [ -f null.zone.file ]; then
          grep -q 'include "/etc/zone/data/ad-blocker.db";' null.zone.file || echo 'include "/etc/zone/data/ad-blocker.db";' >> null.zone.file

          # Rebuild master null.zone.file
          cd ${ZoneMasterDir}
          rm -f null.zone.file
          Now=$(date +"%y%m%d%H%M")
          echo '$TTL 86400         ; one day'         >> null.zone.file
          echo '@ IN    SOA   ns.null.zone.file. mail.null.zone.file. (' >> null.zone.file
    #      echo '      2013091200   ; serial number YYYYMMDDNN'      >> null.zone.file
          echo '      '${Now}'   ; serial number YYYYMMDDNN'      >> null.zone.file
          echo '      86400      ; refresh   1 day'         >> null.zone.file
          echo '      7200      ; retry   2 hours'      >> null.zone.file
          echo '      864000      ; expire   10 days'      >> null.zone.file
          echo '      86400 )   ; min ttl   1 day'         >> null.zone.file
          echo '   NS   ns.null.zone.file.'               >> null.zone.file
          echo '   A   127.0.0.1'                  >> null.zone.file
          echo '* IN   A   127.0.0.1'               >> null.zone.file
       fi

    # Reload the server config after modifications
       ${RootDir}/script/reload.sh

    exit 0
